@@ -26,7 +26,7 @@ use snarkvm_parameters::{
     testnet1::{NoopProgramSNARKPKParameters, NoopProgramSNARKVKParameters},
     Parameter,
 };
-use snarkvm_utilities::{to_bytes, FromBytes, ToBytes};
+use snarkvm_utilities::{to_bytes_le, FromBytes, ToBytes};
 
 use rand::{CryptoRng, Rng};
 
@@ -67,9 +67,9 @@ impl<C: Testnet1Components> ProgramScheme for NoopProgram<C> {
         let verifying_key = prepared_verifying_key.into();
 
         // Compute the program ID.
-        let id = to_bytes![<C as DPCComponents>::ProgramVerificationKeyCRH::hash(
+        let id = to_bytes_le![<C as DPCComponents>::ProgramVerificationKeyCRH::hash(
             program_verifying_key_crh,
-            &to_bytes![verifying_key]?
+            &to_bytes_le![verifying_key]?
         )?]?;
 
         Ok(Self {
@@ -87,14 +87,15 @@ impl<C: Testnet1Components> ProgramScheme for NoopProgram<C> {
         program_verifying_key_crh: &Self::ProgramVerifyingKeyCRH,
     ) -> Result<Self, ProgramError> {
         let proving_key: <Self::ProofSystem as SNARK>::ProvingKey =
-            FromBytes::read(NoopProgramSNARKPKParameters::load_bytes()?.as_slice())?;
-        let verifying_key =
-            <Self::ProofSystem as SNARK>::VerifyingKey::read(NoopProgramSNARKVKParameters::load_bytes()?.as_slice())?;
+            FromBytes::read_le(NoopProgramSNARKPKParameters::load_bytes()?.as_slice())?;
+        let verifying_key = <Self::ProofSystem as SNARK>::VerifyingKey::read_le(
+            NoopProgramSNARKVKParameters::load_bytes()?.as_slice(),
+        )?;
 
         // Compute the program ID.
-        let program_id = to_bytes![<C as DPCComponents>::ProgramVerificationKeyCRH::hash(
+        let program_id = to_bytes_le![<C as DPCComponents>::ProgramVerificationKeyCRH::hash(
             program_verifying_key_crh,
-            &to_bytes![verifying_key]?
+            &to_bytes_le![verifying_key]?
         )?]?;
 
         Ok(Self {
@@ -145,8 +146,8 @@ impl<C: Testnet1Components> ProgramScheme for NoopProgram<C> {
         }
 
         Ok(Self::Execution {
-            verifying_key: to_bytes![self.verifying_key]?,
-            proof: to_bytes![proof]?,
+            verifying_key: to_bytes_le![self.verifying_key]?,
+            proof: to_bytes_le![proof]?,
         })
     }
 
@@ -158,8 +159,8 @@ impl<C: Testnet1Components> ProgramScheme for NoopProgram<C> {
         )?;
 
         Ok(Self::Execution {
-            verifying_key: to_bytes![self.verifying_key]?,
-            proof: to_bytes![proof]?,
+            verifying_key: to_bytes_le![self.verifying_key]?,
+            proof: to_bytes_le![proof]?,
         })
     }
 
