@@ -20,7 +20,7 @@ use snarkvm_fields::ToConstraintField;
 use snarkvm_marlin::marlin::{MarlinSNARK, UniversalSRS};
 use snarkvm_parameters::{prelude::*, testnet2::*};
 use snarkvm_polycommit::PolynomialCommitment;
-use snarkvm_utilities::bytes::FromBytes;
+use snarkvm_utilities::FromBytes;
 
 use rand::{CryptoRng, Rng};
 use std::io::Result as IoResult;
@@ -104,30 +104,34 @@ impl<C: Testnet2Components> SystemParameters<C> {
 
     /// TODO (howardwu): Inspect what is going on with program_verification_key_commitment.
     pub fn load() -> IoResult<Self> {
-        let account_commitment: C::AccountCommitment =
-            From::from(FromBytes::read(AccountCommitmentParameters::load_bytes()?.as_slice())?);
+        let account_commitment: C::AccountCommitment = From::from(FromBytes::read_le(
+            AccountCommitmentParameters::load_bytes()?.as_slice(),
+        )?);
         let account_encryption_parameters: <C::AccountEncryption as EncryptionScheme>::Parameters =
-            FromBytes::read(AccountEncryptionParameters::load_bytes()?.as_slice())?;
+            FromBytes::read_le(AccountEncryptionParameters::load_bytes()?.as_slice())?;
         let account_encryption: C::AccountEncryption = From::from(account_encryption_parameters);
-        let account_signature: C::AccountSignature =
-            From::from(FromBytes::read(AccountSignatureParameters::load_bytes()?.as_slice())?);
-        let encrypted_record_crh: C::EncryptedRecordCRH =
-            From::from(FromBytes::read(EncryptedRecordCRHParameters::load_bytes()?.as_slice())?);
+        let account_signature: C::AccountSignature = From::from(FromBytes::read_le(
+            AccountSignatureParameters::load_bytes()?.as_slice(),
+        )?);
+        let encrypted_record_crh: C::EncryptedRecordCRH = From::from(FromBytes::read_le(
+            EncryptedRecordCRHParameters::load_bytes()?.as_slice(),
+        )?);
         let inner_circuit_id_crh: C::InnerCircuitIDCRH =
-            From::from(FromBytes::read(InnerCircuitIDCRH::load_bytes()?.as_slice())?);
+            From::from(FromBytes::read_le(InnerCircuitIDCRH::load_bytes()?.as_slice())?);
         let local_data_crh: C::LocalDataCRH =
-            From::from(FromBytes::read(LocalDataCRHParameters::load_bytes()?.as_slice())?);
-        let local_data_commitment: C::LocalDataCommitment = From::from(FromBytes::read(
+            From::from(FromBytes::read_le(LocalDataCRHParameters::load_bytes()?.as_slice())?);
+        let local_data_commitment: C::LocalDataCommitment = From::from(FromBytes::read_le(
             LocalDataCommitmentParameters::load_bytes()?.as_slice(),
         )?);
         let program_verification_key_commitment: C::ProgramVerificationKeyCommitment =
-            From::from(FromBytes::read(&[][..])?);
-        let program_verification_key_crh: C::ProgramVerificationKeyCRH = From::from(FromBytes::read(
+            From::from(FromBytes::read_le(&[][..])?);
+        let program_verification_key_crh: C::ProgramVerificationKeyCRH = From::from(FromBytes::read_le(
             Testnet2ProgramVKCRHParameters::load_bytes()?.as_slice(),
         )?);
-        let record_commitment: C::RecordCommitment =
-            From::from(FromBytes::read(RecordCommitmentParameters::load_bytes()?.as_slice())?);
-        let serial_number_nonce: C::SerialNumberNonceCRH = From::from(FromBytes::read(
+        let record_commitment: C::RecordCommitment = From::from(FromBytes::read_le(
+            RecordCommitmentParameters::load_bytes()?.as_slice(),
+        )?);
+        let serial_number_nonce: C::SerialNumberNonceCRH = From::from(FromBytes::read_le(
             SerialNumberNonceCRHParameters::load_bytes()?.as_slice(),
         )?);
 
@@ -182,7 +186,7 @@ where
 
 impl<C: Testnet2Components> ProgramSNARKUniversalSRS<C> {
     pub fn load() -> IoResult<Self> {
-        Ok(Self(From::from(FromBytes::read(
+        Ok(Self(From::from(FromBytes::read_le(
             UniversalSRSParameters::load_bytes()?.as_slice(),
         )?)))
     }
